@@ -1,7 +1,7 @@
 package Getopt::Long::Subcommand::Dump;
 
-our $DATE = '2016-10-26'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010;
 use strict;
@@ -39,10 +39,18 @@ _
             req => 1,
             pos => 0,
             schema => 'str*',
+            cmdline_aliases => {f=>{}},
         },
         libs => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 1,
             summary => 'Libraries to unshift to @INC when running script',
             schema  => ['array*' => of => 'str*'],
+            cmdline_aliases => {I=>{}},
+        },
+        skip_detect => {
+            schema => ['bool', is=>1],
+            cmdline_aliases => {D=>{}},
         },
     },
 };
@@ -54,11 +62,16 @@ sub dump_getopt_long_subcommand_script {
     my %args = @_;
 
     my $filename = $args{filename} or return [400, "Please specify filename"];
-    my $detres = Getopt::Long::Subcommand::Util::detect_getopt_long_subcommand_script(
-        filename => $filename);
-    return $detres if $detres->[0] != 200;
-    return [412, "File '$filename' is not script using Getopt::Long::Subcommand (".
-        $detres->[3]{'func.reason'}.")"] unless $detres->[2];
+    my $detres;
+    if ($args{skip_detect}) {
+        $detres = [200, "OK (skip_detect)", 1, {"func.module"=>"Getopt::Long::Subcommand", "func.reason"=>"skip detect, forcing"}];
+    } else {
+        $detres = Getopt::Long::Subcommand::Util::detect_getopt_long_subcommand_script(
+            filename => $filename);
+        return $detres if $detres->[0] != 200;
+        return [412, "File '$filename' is not script using Getopt::Long::Subcommand (".
+                    $detres->[3]{'func.reason'}.")"] unless $detres->[2];
+    }
 
     my $libs = $args{libs} // [];
 
@@ -77,18 +90,18 @@ sub dump_getopt_long_subcommand_script {
     if ($stdout =~ /^# BEGIN DUMP $tag\s+(.*)^# END DUMP $tag/ms) {
         $spec = eval $1;
         if ($@) {
-            return [500, "Script '$filename' detected as using ".
-                        "Getopt::Long::Subcommand, but error in eval-ing captured ".
+            return [500, "Script '$filename' looks like using ".
+                        "Getopt::Long::Subcommand, but I got an error in eval-ing captured ".
                             "option spec: $@, raw capture: <<<$1>>>"];
         }
         if (ref($spec) ne 'HASH') {
-            return [500, "Script '$filename' detected as using ".
-                        "Getopt::Long::Subcommand, but didn't get a hash option spec, ".
+            return [500, "Script '$filename' looks like using ".
+                        "Getopt::Long::Subcommand, but I didn't get a hash option spec, ".
                             "raw capture: stdout=<<$stdout>>"];
         }
     } else {
-        return [500, "Script '$filename' detected as using Getopt::Long::Subcommand, ".
-                    "but can't capture option spec, raw capture: ".
+        return [500, "Script '$filename' looks like using Getopt::Long::Subcommand, ".
+                    "but I couldn't capture option spec, raw capture: ".
                         "stdout=<<$stdout>>, stderr=<<$stderr>>"];
     }
 
@@ -112,7 +125,7 @@ Getopt::Long::Subcommand::Dump - Run a Getopt::Long::Subcommand-based script but
 
 =head1 VERSION
 
-This document describes version 0.002 of Getopt::Long::Subcommand::Dump (from Perl distribution Getopt-Long-Subcommand-Dump), released on 2016-10-26.
+This document describes version 0.003 of Getopt::Long::Subcommand::Dump (from Perl distribution Getopt-Long-Subcommand-Dump), released on 2016-10-27.
 
 =head1 FUNCTIONS
 
@@ -149,6 +162,8 @@ Path to the script.
 
 Libraries to unshift to @INC when running script.
 
+=item * B<skip_detect> => I<bool>
+
 =back
 
 Returns an enveloped result (an array).
